@@ -1,8 +1,8 @@
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 # other imports
 import os
-from gatekeep.gatekeep.log import log
+from gatekeep.log import log
 
 log(" --< Starting Gatekeep >--")
 
@@ -36,7 +36,7 @@ if len(missingFiles) > 0:
 
 
 # GK modules
-from gatekeep.gatekeep.errors import *
-from gatekeep.gatekeep import settings
-from gatekeep.gatekeep import users
+from gatekeep.errors import *
+from gatekeep import settings
+from gatekeep import users
 log("Finished Startup")
\ No newline at end of file
