@@ -1,4 +1,4 @@
-from gatekeep.gatekeep.log import log
+from gatekeep.log import log
 
 class WorkInProgress(Exception):
 	log("[ERROR] : WorkInProgress")
