@@ -1,8 +1,8 @@
 import json
 import os
 
-from gatekeep.gatekeep import errors
-from gatekeep.gatekeep.log import log
+from gatekeep import errors
+from gatekeep.log import log
 
 defaultSettings = {
 	"salt":int.from_bytes(os.urandom(32),"big"), # Salt for hashing
